@@ -765,12 +765,12 @@ pd.set_option('display.width',1000)
 # print(data)
 
 
-data = ng.get_allStock()
-print(data)
-
-# 获取A股所有股票代码+退市
-data = ng.get_allStockNew()
-print(data)
+# data = ng.get_allStock()
+# print(data)
+#
+# # 获取A股所有股票代码+退市
+# data = ng.get_allStockNew()
+# print(data)
 
 
 
@@ -950,6 +950,9 @@ t1 = time.time()
 # print(data)
 
 
+a = ng.return_last_trading_day()
+print(a)
+
 
 # a = ng.get_allStockData(adj='qfq', date='2020-01-07')
 # print(a)
@@ -957,7 +960,7 @@ t1 = time.time()
 
 # stock_close_df = ng.get_stock_data(code='600109.SH', freq='1m', adj='qfq', bars=200)
 # print(stock_close_df)
-# stock_close_df = ng.get_stock_data(code='600109.SH', freq='1m', adj='qfq', start='2020-12-07', end='2020-12-09')
+# stock_close_df = ng.get_stock_data(code='600109.SH', freq='30m', adj='qfq', start='2015-12-07', end='2018-12-09')
 # print(stock_close_df)
 # stock_close_df = ng.get_stock_data(code='600109.SH', freq='1m', adj='qfq', start='2020-12-07 10:30:00', end='2020-12-09 14:30:00')
 # print(stock_close_df)
